@@ -70,9 +70,7 @@ olink_boxplot <- function(df,
         stop(paste0('The ... option only takes the coloroption argument. ... currently contains the variable ',
                     ellipsis_variables,
                     '.'))
-
       }
-
     }else{
 
       stop(paste0('The ... option only takes one argument. ... currently contains the variables ',
@@ -80,16 +78,17 @@ olink_boxplot <- function(df,
                   '.'))
     }
   }
-  
+
   # Exclude OlinkIDs with missing NPX
   npx_check <- npxCheck(df)
-  
+  # Rename duplicate UniProts
+  df <- uniprot_replace(df, npx_check)
 
   #Filtering on valid OlinkID
   df <- df |>
     dplyr::filter(stringr::str_detect(OlinkID,
-                                      "OID[0-9]{5}")) |> 
-    dplyr::filter(!(OlinkID %in% npx_check$all_nas)) 
+                                      "OID[0-9]{5}")) |>
+    dplyr::filter(!(OlinkID %in% npx_check$all_nas))
 
   #Column setup
   columns_for_npx_data <- c("OlinkID","UniProt","Assay", "NPX", eval(variable))
@@ -97,13 +96,11 @@ olink_boxplot <- function(df,
   #Testing that needed columns are correct
   if(!(all(columns_for_npx_data %in% colnames(df)))){
 
-
     stop(paste0("Column(s) ",
                 paste(setdiff(columns_for_npx_data,
                               colnames(df)),
                       collapse=", "),
                 " not found in NPX data frame!"))
-
   }
 
   if (length(variable) > 2){
@@ -144,7 +141,6 @@ olink_boxplot <- function(df,
 
     assays_for_plotting <- olinkid_list[c(from_protein:(to_protein-1))]
 
-
     npx_for_plotting <- df |>
       dplyr::filter(OlinkID %in% assays_for_plotting) |>
       dplyr::mutate(OlinkID = factor(OlinkID, levels = assays_for_plotting)) |>
@@ -188,6 +184,8 @@ olink_boxplot <- function(df,
         dplyr::left_join(scale_inf, by = "Name_OID") |>
         dplyr::mutate(C1=sapply(strsplit(as.character(contrast)," - "),function(x) x[1]),
                       C2=sapply(strsplit(as.character(contrast)," - "),function(x) x[2])) |>
+        dplyr::mutate(C1=stringr::str_replace_all(C1,"\\(|\\)", ""),
+                      C2=stringr::str_replace_all(C2,"\\(|\\)", "")) |>
         dplyr::group_by(Name_OID, contrast) |>
         dplyr::mutate(c.sort=min(C1,C2)) |>
         dplyr::mutate(p.value=paste0(myRound(Adjusted_pval)," Contrast: ", contrast)) |>
