@@ -110,13 +110,20 @@ olink_pathway_enrichment <- function(data, test_results, method = "GSEA", ontolo
          BiocManager::install(\"clusterProfiler\")")
   }
 
-  if(!requireNamespace("msigdbr", quietly = TRUE)) {
-    stop(" Pathway enrichment requires msigdbr package.
-         Please install msigdbr before continuing.
+  if(!requireNamespace("msigdbr", minVersion = "9.0.0", quietly = TRUE)) {
+    stop(" Pathway enrichment requires version >=9.0.0 of the msigdbr package.
+         Please install a supported version of msigdbr before continuing.
 
          install.packages(\"msigdbr\")")
   }
 
+  if(!rlang::is_installed(pkg = "msigdbdf")) {
+    stop(" Pathway enrichment requires msigdbdf package.
+         Please install msigdbdf before continuing.
+
+         install.packages(\"msigdbdf\", repos = c(\"https://igordot.r-universe.dev\", \"https://cloud.r-project.org\"))")
+  }
+
   # Data Checks
   if(length(unique(data$OlinkID)) != length(unique(test_results$OlinkID))) {
     warning("The number of Olink IDs in the data does not equal the number of Olink IDs in the test results.")
@@ -165,19 +172,23 @@ olink_pathway_enrichment <- function(data, test_results, method = "GSEA", ontolo
 data_prep <- function(data) {
   # Remove NA data and filter for valid Olink IDs
   npx_check <- npxCheck(data)
+
+  # Rename duplicate UniProts
+  data <- uniprot_replace(data, npx_check)
+
   data <- data %>%
     dplyr::filter(!(OlinkID %in% npx_check$all_nas)) %>%
     dplyr::filter(stringr::str_detect(OlinkID,
                                       "OID[0-9]{5}"))
   # For data missing LOD column
-  alt_plate_lods <- c("Plate LOD", "PlateLOD", "plateLOD", "Plate_LOD")
+  alt_plate_lods <- c("Plate LOD", "PlateLOD", "plateLOD", "Plate_LOD", "LODNPX")
   alt_max_lods <- c("Max LOD", "MaxLOD", "maxLOD", "Max_LOD")
   if(!("LOD" %in% names(data))){
-    if(any(alt_plate_lods %in% names(df))){
+    if(any(alt_plate_lods %in% names(data))){
       data <- data |>
         dplyr::rename(LOD = any_of(alt_plate_lods))
     }
-    else if(any(alt_max_lods %in% names(df))){
+    else if(any(alt_max_lods %in% names(data))){
       data <- data |>
         dplyr::rename(LOD = any_of(alt_max_lods))
     }
@@ -185,12 +196,12 @@ data_prep <- function(data) {
       data$LOD <- -Inf
     }
   }
-  
+
   # For data with SampleQC instead of QC_Warning
   if("SampleQC" %in% names(data)){
     data$QC_Warning <- data$SampleQC
   }
-  
+
   # Filter highest detectibility for repeated IDs
   olink_ids <- data %>%
     dplyr::filter(!stringr::str_detect(string = SampleID, pattern = "CONTROL*.")) %>%
@@ -233,25 +244,25 @@ results_to_genelist <- function(test_results) {
 
 select_db <- function(ontology = ontology, organism = organism){
   if (organism == "human") {
-    msig_df <- msigdbr::msigdbr(species = "Homo sapiens", category = "C2") %>%
-      rbind(msigdbr::msigdbr(species = "Homo sapiens", category = "C5"))
+    msig_df <- msigdbr::msigdbr(species = "Homo sapiens", collection = "C2") %>%
+      rbind(msigdbr::msigdbr(species = "Homo sapiens", collection = "C5"))
   } else if (organism == "mouse") {
-    msig_df <- msigdbr::msigdbr(species = "Mus musculus", category = "C2") %>%
-      rbind(msigdbr::msigdbr(species = "Mus musculus", category = "C5"))
+    msig_df <- msigdbr::msigdbr(species = "Mus musculus", collection = "C2") %>%
+      rbind(msigdbr::msigdbr(species = "Mus musculus", collection = "C5"))
   }
 
   if (ontology == "Reactome") {
     message("Extracting Reactome Database from MSigDB...")
     msig_df <- msig_df %>%
-      dplyr::filter(gs_subcat == "CP:REACTOME")
+      dplyr::filter(gs_subcollection == "CP:REACTOME")
   } else if (ontology == "KEGG") {
     message("Extracting KEGG Database from MSigDB...")
     msig_df <- msig_df %>%
-      dplyr::filter(gs_subcat == "CP:KEGG")
+      dplyr::filter(gs_subcollection == "CP:KEGG_MEDICUS")
   } else if (ontology == "GO") {
     message("Extracting GO Database from MSigDB...")
     msig_df <- msig_df %>%
-      dplyr::filter(gs_subcat %in% c("GO:BP", "GO:CC", "GO:MF"))
+      dplyr::filter(gs_subcollection %in% c("GO:BP", "GO:CC", "GO:MF"))
   } else {
     message("Using MSigDB...")
   }
@@ -271,7 +282,14 @@ gsea_pathwayenrichment <- function(geneList, msig_df) {
 
   GSEA <- clusterProfiler::GSEA(geneList = geneList, TERM2GENE = msig_df, pvalueCutoff = 1)
 
-  return(GSEA@result)
+  if (is.null(GSEA)) {
+    cli::cli_warn(
+      "No remaining pathways within the range 10-500 proteins!"
+    )
+    return(NULL)
+  } else {
+    return(GSEA@result)
+  }
 }
 
 ora_pathwayenrichment <- function(test_results, msig_df, pvalue_cutoff = pvalue_cutoff, estimate_cutoff = estimate_cutoff) {
@@ -293,5 +311,12 @@ ora_pathwayenrichment <- function(test_results, msig_df, pvalue_cutoff = pvalue_
 
   ORA <- clusterProfiler::enricher(gene = sig_genes, universe = universe, TERM2GENE = msig_df, pvalueCutoff = 1)
 
-  return(ORA@result)
+  if (is.null(ORA)) {
+    cli::cli_warn(
+      "No remaining pathways within the range 10-500 proteins!"
+    )
+    return(NULL)
+  } else {
+    return(ORA@result)
+  }
 }
