@@ -6,17 +6,17 @@
 #' @param lod_method method for calculating LOD using either "FixedLOD" or
 #' negative controls ("NCLOD"), or both ("Both"). Default `NCLOD`.
 #'
-#' @return A dataframe with 2 additional columns, LOD and PCNormalizedLOD if `lod_method` is FixedLOD or NCLOD. When `Normalization = "Plate Control"`, LOD and PCNormalizedLOD are identical. 
-#' 
-#' If `lod_method` is "Both", 4 additional columns will be added: 
+#' @return A dataframe with 2 additional columns, LOD and PCNormalizedLOD if `lod_method` is FixedLOD or NCLOD. When `Normalization = "Plate Control"`, LOD and PCNormalizedLOD are identical.
+#'
+#' If `lod_method` is "Both", 4 additional columns will be added:
 #'  \itemize{
 #'    \item NCLOD - LOD calculated from negative controls and normalized based on normalization column
 #'    \item NCPCNormalizedLOD - PC Normalized LOD calculated from negative controls
 #'    \item FixedLOD - LOD calculated from fixed LOD file and normalized based on normalization column
 #'    \item FixedPCNormalizedLOD - PC Normalized LOD calculated from fixed LOD file
 #'    }
-#'  
-#' 
+#'
+#'
 #' @export
 #' @examples
 #' \dontrun{
@@ -41,37 +41,42 @@
 #' }
 #'
 olink_lod <- function(data, lod_file_path = NULL, lod_method = "NCLOD"){
+  #Check data format
+  npxCheck <- npxCheck(df)
+  # Rename duplicate UniProts
+  df <- uniprot_replace(df, npxCheck)
+
   # lod_method must be one of options
   if(!lod_method %in% c("NCLOD", "FixedLOD", "Both")){
     stop("`lod_method` must be one of \"NCLOD\", \"FixedLOD\", or \"Both\"")
   }
-  
+
   # If lod method is both or fixed you need the file
   if(missing(lod_file_path) & lod_method %in% c("Both", "FixedLOD")) {
     stop(paste0("`lod_file_path` must be specified for lod_method = \"",
                 lod_method, "\""))
   }
-  
+
   req_columns <- c("SampleType", "OlinkID", "DataAnalysisRefID", "SampleQC", "AssayType", "NPX")
   missingcols <- setdiff(req_columns, names(data))
   if (length(missingcols) != 0){
     stop(paste0("Required column(s) not found: ", paste0(missingcols, collapse = ", ")))
   }
-  
-  
+
+
   if (lod_method == "Both"){
-    data_nc <- olink_lod_internal(data, lod_file_path, lod_method = "NCLOD") |> 
+    data_nc <- olink_lod_internal(data, lod_file_path, lod_method = "NCLOD") |>
       rename("NCLOD" = "LOD",
              "NCPCNormalizedLOD" = "PCNormalizedLOD")
-    data_fixed <- olink_lod_internal(data, lod_file_path, lod_method = "FixedLOD") |> 
+    data_fixed <- olink_lod_internal(data, lod_file_path, lod_method = "FixedLOD") |>
       rename("FixedLOD" = "LOD",
              "FixedPCNormalizedLOD" = "PCNormalizedLOD")
-    
+
     data <- dplyr::full_join(data_nc, data_fixed,by =  names(data))
-    
+
   }else{
-    data<- olink_lod_internal(data = data, 
-                              lod_file_path = lod_file_path, 
+    data<- olink_lod_internal(data = data,
+                              lod_file_path = lod_file_path,
                               lod_method = lod_method)
   }
   return(data)
@@ -79,31 +84,31 @@ olink_lod <- function(data, lod_file_path = NULL, lod_method = "NCLOD"){
 
 
 olink_lod_internal <- function(data, lod_file_path = NULL, lod_method = "NCLOD"){
-  
+
   # store original column names of `data` to restore them later
   original_columns <- names(data)
-  
+
   # check the type of LOD calculation to perform and compute or extract:
   # LODNPX, LODCount and LODMethod
-  
+
   lod_methods <- list(fix_lod = "FixedLOD",
                       nc_lod = "NCLOD")
-  
+
   if (lod_method == lod_methods$fix_lod) {
-    
+
     lod_file <- read.table(file = lod_file_path, sep = ";", header = TRUE)
     lod_data <- olink_fixed_lod(data_analysis_ref_id = data$DataAnalysisRefID,
                                 lod_file = lod_file)
-    
+
   } else if (lod_method == lod_methods$nc_lod) {
-    
+
     lod_data <- olink_nc_lod(data = data)
-    
+
   } else {
-    
+
     stop(paste0("lod_method must be one of \"", lod_methods$fix_lod, "\" or \"",
                 lod_methods$nc_lod, "\"", "or \"Both\""))
-    
+
   }
 
 
@@ -128,13 +133,13 @@ olink_lod_internal <- function(data, lod_file_path = NULL, lod_method = "NCLOD")
         c(original_columns, "LOD", "PCNormalizedLOD")
       )
     )
-  
+
   return(data)
 }
 
 # extract LODNPX, LODCount and LODMethods from reference file
 olink_fixed_lod <- function(data_analysis_ref_id, lod_file) {
-  
+
   lod_file |>
     dplyr::filter(
       .data[["DataAnalysisRefID"]] %in% data_analysis_ref_id
@@ -144,13 +149,13 @@ olink_fixed_lod <- function(data_analysis_ref_id, lod_file) {
         c("OlinkID", "DataAnalysisRefID", "LODNPX", "LODCount", "LODMethod")
       )
     )
-  
+
 }
 
 # compute LODNPX, LODCount and LODMethods from NCs
 olink_nc_lod <- function(data, min_num_nc = 10L) {
   # Calculate LOD in counts and NPX
-  
+
   # rows from NC
   lod_data <- data |>
     dplyr::filter(
@@ -159,13 +164,13 @@ olink_nc_lod <- function(data, min_num_nc = 10L) {
       & .data[["AssayType"]] == "assay"
       & !is.na(.data[["NPX"]])
     )
-  
+
   # check that we have at least `min_num_nc` NCs
   if(length(unique(lod_data$SampleID)) < min_num_nc){
     stop(paste("At least", min_num_nc, "Negative Controls are required to",
                "calculate LOD from Negative Controls."))
   }
-  
+
   # compute LOD
   lod_data <- lod_data |>
     # LOD is comnputed per assay and lot of reagents
@@ -190,14 +195,14 @@ olink_nc_lod <- function(data, min_num_nc = 10L) {
         c("MaxCount")
       )
     )
-  
+
   return(lod_data)
-  
+
 }
 
 pc_norm_count <- function(data, lod_data){
   # Calculate PC median for normalization
-  
+
   pc_median <- data |>
     dplyr::group_by(
       OlinkID, PlateID
@@ -211,11 +216,11 @@ pc_norm_count <- function(data, lod_data){
         c("OlinkID", "PlateID", "PCMedian")
       )
     )
-  
+
   if(nrow(pc_median) == 0L){
     stop("Insufficient Plate Control data for normalization of LOD.")
   }
-  
+
   # Calculate ExtCount for normalization
   ext_count <- data |>
     dplyr::filter(
@@ -227,7 +232,7 @@ pc_norm_count <- function(data, lod_data){
           "ExtCount" = "Count")
       )
     )
-  
+
   data <- data |>
     dplyr::left_join(
       lod_data,
@@ -241,9 +246,9 @@ pc_norm_count <- function(data, lod_data){
       ext_count,
       by = c("SampleID", "WellID", "Panel", "Block", "SampleType", "PlateID")
     )
-  
+
   # Convert count LOD to PC norm NPX
-  
+
   data <- data |>
     dplyr::mutate(
       PCNormalizedLOD = dplyr::case_when(
@@ -253,16 +258,16 @@ pc_norm_count <- function(data, lod_data){
         TRUE ~ log2(.data[["LODCount"]] / .data[["ExtCount"]]) - .data[["PCMedian"]],
         .default = NA_real_
       )
-    ) |> 
+    ) |>
     dplyr::mutate(LOD = PCNormalizedLOD)
-  
+
   return(data)
 }
 
 int_norm_count <- function(data, lod_data){
-  
+
   data <- pc_norm_count(data, lod_data)
-  
+
   if(any(data[["Normalization"]]=="Intensity")){
     plate_median <- data |>
       dplyr::filter(
@@ -279,11 +284,11 @@ int_norm_count <- function(data, lod_data){
         dplyr::all_of(
           c("OlinkID", "PlateID", "PlateMedianNPX"))
       )
-    
+
     if(nrow(plate_median) == 0L){
       stop("Insufficient data for intensity normalization of LOD.")
     }
-    
+
     data <- data |>
       dplyr::left_join(
         plate_median,
@@ -293,7 +298,7 @@ int_norm_count <- function(data, lod_data){
         LOD = .data[["PCNormalizedLOD"]] - .data[["PlateMedianNPX"]]
       )
   }
-  
+
   return(data)
-  
-}
\ No newline at end of file
+
+}
